[Libreoffice-commits] core.git: include/svtools sc/inc sc/source

Johnny_M klasse at partyheld.de
Wed Feb 15 19:05:19 UTC 2017


 include/svtools/rtftoken.h         |   18 +++++-----
 sc/inc/autoform.hxx                |   10 +----
 sc/source/core/tool/ddelink.cxx    |   52 ++++++++++++++---------------
 sc/source/core/tool/editutil.cxx   |   28 +++++++--------
 sc/source/core/tool/rangelst.cxx   |   66 ++++++++++++++++++-------------------
 sc/source/core/tool/refupdat.cxx   |   36 ++++++++++----------
 sc/source/core/tool/stringutil.cxx |    2 -
 sc/source/core/tool/viewopti.cxx   |    6 +--
 8 files changed, 106 insertions(+), 112 deletions(-)

New commits:
commit c0089c104de4758dae6e3d732d4f5ff2c6fd5074
Author: Johnny_M <klasse at partyheld.de>
Date:   Fri Feb 3 17:44:50 2017 +0000

    Translate German comments
    
    Change-Id: Ia30dc2f96b34e0edecade84a020092b0a24cbb18
    Reviewed-on: https://gerrit.libreoffice.org/33895
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Michael Meeks <michael.meeks at collabora.com>
    Tested-by: Michael Meeks <michael.meeks at collabora.com>

diff --git a/include/svtools/rtftoken.h b/include/svtools/rtftoken.h
index cb23f30..550a36f 100644
--- a/include/svtools/rtftoken.h
+++ b/include/svtools/rtftoken.h
@@ -24,7 +24,7 @@ namespace rtl {
   class OUString;
 };
 
-// suche die TokenID zu dem Token
+// search the TokenID for the token
 int GetRTFToken( const rtl::OUString& rSearch );
 
 enum RTF_TOKEN_RANGES {
@@ -43,10 +43,10 @@ enum RTF_TOKEN_RANGES {
     RTF_OBJECTS                     = 0x0D00,
     RTF_NUMBULLETS                  = 0x0E00,
 
-    // !!! kann hinein verodert werden (Border/Background) !!!!
+    // !!! can be mixed in using the "or" operator (border/background) !!!!
     RTF_TABLEDEF                    = 0x1000,
 
-    // !!! kann hinein verodert werden (Border/Tab) !!!!
+    // !!! can be mixed in using the "or" operator (border/tab) !!!!
     RTF_SWGDEFS                     = 0x4000
 };
 
@@ -179,7 +179,7 @@ enum RTF_TOKEN_IDS {
     RTF_BLIPUID,
     RTF_BLIPUPI,
 
-    RTF_FIELD,                      // Felder
+    RTF_FIELD,                      // Fields
     RTF_FLDDIRTY,
     RTF_FLDEDIT,
     RTF_FLDLOCK,
@@ -520,7 +520,7 @@ enum RTF_TOKEN_IDS {
     RTF_SECTSPECIFYCL,
     RTF_SECTSPECIFYL,
 
-    // Swg-Header/Footer-Tokens
+    // Swg header/footer tokens
     RTF_HEADER_YB   = (RTF_SECTFMT|RTF_SWGDEFS),
     RTF_HEADER_XL,
     RTF_HEADER_XR,
@@ -629,7 +629,7 @@ enum RTF_TOKEN_IDS {
     RTF_TLTH,
     RTF_TLEQ,
 
-    // Swg-TabStop-Tokens
+    // Swg TabStop tokens
     RTF_TLSWG = (RTF_TABSTOPDEF|RTF_SWGDEFS),
 
 /*  */
@@ -655,7 +655,7 @@ enum RTF_TOKEN_IDS {
     RTF_BRDROUTSET,
     RTF_BRDRFRAME,
 
-    // Swg-Border-Tokens
+    // Swg border tokens
     RTF_BRDBOX          = (RTF_BRDRDEF|RTF_SWGDEFS),
     RTF_BRDLINE_COL,
     RTF_BRDLINE_IN,
@@ -793,7 +793,7 @@ enum RTF_TOKEN_IDS {
     RTF_TWOINONE,
     RTF_HORZVERT,
 
-    // Swg-Border-Tokens
+    // Swg border tokens
     RTF_SWG_ESCPROP     = (RTF_CHRFMT|RTF_SWGDEFS),
     RTF_HYPHEN,
     RTF_HYPHLEAD,
@@ -882,7 +882,7 @@ enum RTF_TOKEN_IDS {
     RTF_FRMTXLRTBV,
     RTF_FRMTXTBRLV,
 
-    // Swg-Frame-Tokens
+    // Swg frame tokens
     RTF_FLYPRINT = (RTF_APOCTL|RTF_SWGDEFS),
     RTF_FLYOPAQUE,
     RTF_FLYPRTCTD,
diff --git a/sc/inc/autoform.hxx b/sc/inc/autoform.hxx
index 69dd61f..66ff572 100644
--- a/sc/inc/autoform.hxx
+++ b/sc/inc/autoform.hxx
@@ -23,14 +23,8 @@
 /*************************************************************************
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-    Die akt. Struktur der Autoformatierung darf nicht mehr veraendert werden.
-    Diese wird durch unterschiedlichen Code vom StartWriter und vom StarCalc
-    eingelesen/geschrieben.
-    Sollte sich doch mal eine Aenderung nicht vermeiden lassen, dann auf
-    jedenfall in beiden Applikationen aendern.
-
-    The structure of table auto formatting should not changed. It is used
-    by different code of Writer and Calc. If a change is necessary, the
+    The structure of auto formatting should not be changed. It is used
+    by various code of Writer and Calc. If a change is necessary, the
     source code of both applications must be changed!
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
diff --git a/sc/source/core/tool/ddelink.cxx b/sc/source/core/tool/ddelink.cxx
index 5390726..f46b0fa 100644
--- a/sc/source/core/tool/ddelink.cxx
+++ b/sc/source/core/tool/ddelink.cxx
@@ -54,7 +54,7 @@ ScDdeLink::ScDdeLink( ScDocument* pD, const OUString& rA, const OUString& rT, co
 
 ScDdeLink::~ScDdeLink()
 {
-    // Verbindung aufheben
+    // cancel connection
 
     // pResult is refcounted
 }
@@ -91,7 +91,7 @@ ScDdeLink::ScDdeLink( ScDocument* pD, SvStream& rStream, ScMultipleReadHeader& r
     if ( bHasValue )
         pResult = new ScFullMatrix(0, 0);
 
-    if (rHdr.BytesLeft())       // neu in 388b und der 364w (RealTime-Client) Version
+    if (rHdr.BytesLeft())       // new in 388b and the 364w (RealTime Client) version
         rStream.ReadUChar( nMode );
     else
         nMode = SC_DDE_DEFAULT;
@@ -111,11 +111,11 @@ void ScDdeLink::Store( SvStream& rStream, ScMultipleWriteHeader& rHdr ) const
     bool bHasValue = ( pResult != nullptr );
     rStream.WriteBool( bHasValue );
 
-    if( rStream.GetVersion() > SOFFICE_FILEFORMAT_40 )      // nicht bei 4.0 Export
-        rStream.WriteUChar( nMode );                                   // seit 388b
+    if( rStream.GetVersion() > SOFFICE_FILEFORMAT_40 )      // not with 4.0 Export
+        rStream.WriteUChar( nMode );                                   // since 388b
 
-    //  Links mit Mode != SC_DDE_DEFAULT werden bei 4.0 Export komplett weggelassen
-    //  (aus ScDocument::SaveDdeLinks)
+    //  links with Mode != SC_DDE_DEFAULT are completely omitted in 4.0 Export
+    //  (from ScDocument::SaveDdeLinks)
 
     rHdr.EndEntry();
 }
@@ -123,7 +123,7 @@ void ScDdeLink::Store( SvStream& rStream, ScMultipleWriteHeader& rHdr ) const
 sfx2::SvBaseLink::UpdateResult ScDdeLink::DataChanged(
     const OUString& rMimeType, const css::uno::Any & rValue )
 {
-    //  wir koennen nur Strings...
+    //  we only master strings...
     if ( SotClipboardFormatId::STRING != SotExchange::GetFormatIdFromMimeType( rMimeType ))
         return SUCCESS;
 
@@ -131,14 +131,14 @@ sfx2::SvBaseLink::UpdateResult ScDdeLink::DataChanged(
     ScByteSequenceToString::GetString( aLinkStr, rValue, DDE_TXT_ENCODING );
     aLinkStr = convertLineEnd(aLinkStr, LINEEND_LF);
 
-    //  wenn String mit Zeilenende aufhoert, streichen:
+    //  if string ends with line end, discard:
 
     sal_Int32 nLen = aLinkStr.getLength();
     if (nLen && aLinkStr[nLen-1] == '\n')
         aLinkStr = aLinkStr.copy(0, nLen-1);
 
     OUString aLine;
-    SCSIZE nCols = 1;       // Leerstring -> eine leere Zelle
+    SCSIZE nCols = 1;       // empty string -> an empty line
     SCSIZE nRows = 1;
     if (!aLinkStr.isEmpty())
     {
@@ -148,26 +148,26 @@ sfx2::SvBaseLink::UpdateResult ScDdeLink::DataChanged(
             nCols = static_cast<SCSIZE>(comphelper::string::getTokenCount(aLine, '\t'));
     }
 
-    if (!nRows || !nCols)               // keine Daten
+    if (!nRows || !nCols)               // no data
     {
         pResult.reset();
     }
-    else                                // Daten aufteilen
+    else                                // split data
     {
-        //  Matrix immer neu anlegen, damit bIsString nicht durcheinanderkommt
+        //  always newly re-create matrix, so that bIsString doesn't get mixed up
         pResult = new ScFullMatrix(nCols, nRows, 0.0);
 
         SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
         svl::SharedStringPool& rPool = pDoc->GetSharedStringPool();
 
-        //  nMode bestimmt, wie der Text interpretiert wird (#44455#/#49783#):
-        //  SC_DDE_DEFAULT - Zahlformat aus Zellvorlage "Standard"
-        //  SC_DDE_ENGLISH - Standard-Zahlformat fuer English/US
-        //  SC_DDE_TEXT    - ohne NumberFormatter direkt als String
+        //  nMode determines how the text is interpreted (#44455#/#49783#):
+        //  SC_DDE_DEFAULT - number format from cell template "Standard"
+        //  SC_DDE_ENGLISH - standard number format for English/US
+        //  SC_DDE_TEXT    - without NumberFormatter directly as string
         sal_uLong nStdFormat = 0;
         if ( nMode == SC_DDE_DEFAULT )
         {
-            ScPatternAttr* pDefPattern = pDoc->GetDefPattern();     // enthaelt Standard-Vorlage
+            ScPatternAttr* pDefPattern = pDoc->GetDefPattern();     // contains standard template
             if ( pDefPattern )
                 nStdFormat = pDefPattern->GetNumberFormat( pFormatter );
         }
@@ -194,18 +194,18 @@ sfx2::SvBaseLink::UpdateResult ScDdeLink::DataChanged(
         }
     }
 
-    //  Es hat sich was getan...
+    //  Something happened...
 
     if (HasListeners())
     {
         Broadcast(ScHint(SfxHintId::ScDataChanged, ScAddress()));
-        pDoc->TrackFormulas();      // muss sofort passieren
+        pDoc->TrackFormulas();      // must happen immediatelly
         pDoc->StartTrackTimer();
 
-        //  StartTrackTimer ruft asynchron TrackFormulas, Broadcast(FID_DATACHANGED),
-        //  ResetChanged, SetModified und Invalidate(SID_SAVEDOC/SID_DOC_MODIFIED)
-        //  TrackFormulas zusaetzlich nochmal sofort, damit nicht z.B. durch IdleCalc
-        //  eine Formel berechnet wird, die noch im FormulaTrack steht (#61676#)
+        //  StartTrackTimer asynchronously calls TrackFormulas, Broadcast(FID_DATACHANGED),
+        //  ResetChanged, SetModified and Invalidate(SID_SAVEDOC/SID_DOC_MODIFIED)
+        //  TrackFormulas additionally once again immediatelly, so that, e.g., a formula still
+        //  located in the FormulaTrack doesn't get calculated by IdleCalc (#61676#)
 
         //  notify Uno objects (for XRefreshListener)
         //  must be after TrackFormulas
@@ -221,14 +221,14 @@ sfx2::SvBaseLink::UpdateResult ScDdeLink::DataChanged(
 void ScDdeLink::ListenersGone()
 {
     bool bWas = bIsInUpdate;
-    bIsInUpdate = true;             // Remove() kann Reschedule ausloesen??!?
+    bIsInUpdate = true;             // Remove() can trigger reschedule??!?
 
     ScDocument* pStackDoc = pDoc;   // member pDoc can't be used after removing the link
 
     sfx2::LinkManager* pLinkMgr = pDoc->GetLinkManager();
     pLinkMgr->Remove( this);        // deletes this
 
-    if ( pLinkMgr->GetLinks().empty() )            // letzten geloescht ?
+    if ( pLinkMgr->GetLinks().empty() )            // deleted the last one ?
     {
         SfxBindings* pBindings = pStackDoc->GetViewBindings();      // don't use member pDoc!
         if (pBindings)
@@ -251,7 +251,7 @@ void ScDdeLink::SetResult( const ScMatrixRef& pRes )
 void ScDdeLink::TryUpdate()
 {
     if (bIsInUpdate)
-        bNeedUpdate = true;         // kann jetzt nicht ausgefuehrt werden
+        bNeedUpdate = true;         // cannot be executed now
     else
     {
         bIsInUpdate = true;
diff --git a/sc/source/core/tool/editutil.cxx b/sc/source/core/tool/editutil.cxx
index fa0f99d..32d4a42 100644
--- a/sc/source/core/tool/editutil.cxx
+++ b/sc/source/core/tool/editutil.cxx
@@ -50,7 +50,7 @@
 
 using namespace com::sun::star;
 
-//  Delimiters zusaetzlich zu EditEngine-Default:
+//  delimiters additionally to EditEngine default:
 
 ScEditUtil::ScEditUtil( ScDocument* pDocument, SCCOL nX, SCROW nY, SCTAB nZ,
                             const Point& rScrPosPixel,
@@ -271,8 +271,8 @@ OUString ScEditUtil::GetCellFieldValue(
             aRet = "?";
     }
 
-    if (aRet.isEmpty())        // leer ist baeh
-        aRet = " ";         // Space ist Default der Editengine
+    if (aRet.isEmpty())        // empty is yuck
+        aRet = " ";         // space is default of EditEngine
 
     return aRet;
 }
@@ -312,9 +312,9 @@ Rectangle ScEditUtil::GetEditArea( const ScPatternAttr* pPattern, bool bForceToT
         nIndent = static_cast<const SfxUInt16Item&>(pPattern->GetItem(ATTR_INDENT)).GetValue();
     long nPixDifX   = (long) ( ( pMargin->GetLeftMargin() + nIndent ) * nPPTX );
     aStartPos.X()   += nPixDifX * nLayoutSign;
-    nCellX          -= nPixDifX + (long) ( pMargin->GetRightMargin() * nPPTX );     // wegen Umbruch etc.
+    nCellX          -= nPixDifX + (long) ( pMargin->GetRightMargin() * nPPTX );     // due to line feed, etc.
 
-    //  vertikale Position auf die in der Tabelle anpassen
+    //  align vertical position to the one in the table
 
     long nPixDifY;
     long nTopMargin = (long) ( pMargin->GetTopMargin() * nPPTY );
@@ -336,7 +336,7 @@ Rectangle ScEditUtil::GetEditArea( const ScPatternAttr* pPattern, bool bForceToT
         long nTextHeight = pDoc->GetNeededSize( nCol, nRow, nTab,
                                                 pDev, nPPTX, nPPTY, aZoomX, aZoomY, false );
         if (!nTextHeight)
-        {                                   // leere Zelle
+        {                                   // empty cell
             vcl::Font aFont;
             // font color doesn't matter here
             pPattern->GetFont( aFont, SC_AUTOCOL_BLACK, pDev, &aZoomY );
@@ -348,7 +348,7 @@ Rectangle ScEditUtil::GetEditArea( const ScPatternAttr* pPattern, bool bForceToT
         pDev->SetMapMode(aMode);
 
         if ( nTextHeight > nCellY + nTopMargin || bForceToTop )
-            nPixDifY = 0;                           // zu gross -> oben anfangen
+            nPixDifY = 0;                           // too large -> begin at the top
         else
         {
             if ( eJust == SVX_VER_JUSTIFY_CENTER )
@@ -364,7 +364,7 @@ Rectangle ScEditUtil::GetEditArea( const ScPatternAttr* pPattern, bool bForceToT
     if ( bLayoutRTL )
         aStartPos.X() -= nCellX - 2;    // excluding grid on both sides
 
-                                                        //  -1 -> Gitter nicht ueberschreiben
+                                                        //  -1 -> don't overwrite grid
     return Rectangle( aStartPos, Size(nCellX-1,nCellY-1) );
 }
 
@@ -411,7 +411,7 @@ ScEditAttrTester::ScEditAttrTester( ScEditEngineDefaulter* pEng ) :
             }
         }
 
-        //  Feldbefehle enthalten?
+        //  contains field commands?
 
         SfxItemState eFieldState = pEditAttrs->GetItemState( EE_FEATURE_FIELD, false );
         if ( eFieldState == SfxItemState::DONTCARE || eFieldState == SfxItemState::SET )
@@ -714,13 +714,13 @@ void ScTabEditEngine::Init( const ScPatternAttr& rPattern )
     SfxItemSet* pEditDefaults = new SfxItemSet( GetEmptyItemSet() );
     rPattern.FillEditItemSet( pEditDefaults );
     SetDefaults( pEditDefaults );
-    // wir haben keine StyleSheets fuer Text
+    // we have no StyleSheets for text
     SetControlWord( GetControlWord() & ~EEControlBits::RTFSTYLESHEETS );
 }
 
-//      Feldbefehle fuer Kopf- und Fusszeilen
+//      field commands for header and footer
 
-//      Zahlen aus \sw\source\core\doc\numbers.cxx
+//      numbers from \sw\source\core\doc\numbers.cxx
 
 static OUString lcl_GetCharStr( sal_Int32 nNo )
 {
@@ -769,7 +769,7 @@ static OUString lcl_GetNumStr(sal_Int32 nNo, SvxNumType eType)
 //      CHAR_SPECIAL:
 //          ????
 
-//      case ARABIC:    ist jetzt default
+//      case ARABIC:    is default now
         default:
             aTmpStr = OUString::number(nNo);
             break;
@@ -846,7 +846,7 @@ OUString ScHeaderEditEngine::CalcFieldValue( const SvxFieldItem& rField,
     return aRet;
 }
 
-//                          Feld-Daten
+//                          field data
 
 ScFieldEditEngine::ScFieldEditEngine(
     ScDocument* pDoc, SfxItemPool* pEnginePoolP,
diff --git a/sc/source/core/tool/refupdat.cxx b/sc/source/core/tool/refupdat.cxx
index 300dd1d..09935a1 100644
--- a/sc/source/core/tool/refupdat.cxx
+++ b/sc/source/core/tool/refupdat.cxx
@@ -76,25 +76,25 @@ static bool lcl_MoveReorder( R& rRef, U nStart, U nEnd, S nDelta )
         return true;
     }
 
-    if ( nDelta > 0 )                   // nach hinten schieben
+    if ( nDelta > 0 )                   // move backward
     {
         if ( rRef >= nStart && rRef <= nEnd + nDelta )
         {
             if ( rRef <= nEnd )
                 rRef = sal::static_int_cast<R>( rRef + nDelta );    // in the moved range
             else
-                rRef -= nEnd - nStart + 1;      // nachruecken
+                rRef -= nEnd - nStart + 1;      // move up
             return true;
         }
     }
-    else                                // nach vorne schieben
+    else                                // move forward
     {
         if ( rRef >= nStart + nDelta && rRef <= nEnd )
         {
             if ( rRef >= nStart )
                 rRef = sal::static_int_cast<R>( rRef + nDelta );    // in the moved range
             else
-                rRef += nEnd - nStart + 1;      // nachruecken
+                rRef += nEnd - nStart + 1;      // move up
             return true;
         }
     }
@@ -135,11 +135,11 @@ bool IsExpand( R n1, R n2, U nStart, S nD )
 {   // before normal Move...
     return
         nD > 0          // Insert
-     && n1 < n2         // mindestens zwei Cols/Rows/Tabs in Ref
+     && n1 < n2         // at least two Cols/Rows/Tabs in Ref
      && (
-        (nStart <= n1 && n1 < nStart + nD)      // n1 innerhalb des Insert
-        || (n2 + 1 == nStart)                   // n2 direkt vor Insert
-        );      // n1 < nStart <= n2 wird sowieso expanded!
+        (nStart <= n1 && n1 < nStart + nD)      // n1 within the Insert
+        || (n2 + 1 == nStart)                   // n2 directly before Insert
+        );      // n1 < nStart <= n2 is expanded anyway!
 }
 
 template< typename R, typename S, typename U >
@@ -151,7 +151,7 @@ void Expand( R& n1, R& n2, U nStart, S nD )
         n2 = sal::static_int_cast<R>( n2 + nD );
         return;
     }
-    // am Anfang
+    // at the beginning
     n1 = sal::static_int_cast<R>( n1 - nD );
 }
 
@@ -340,7 +340,7 @@ ScRefUpdateRes ScRefUpdate::Update( ScDocument* pDoc, UpdateRefMode eUpdateRefMo
     }
     else if (eUpdateRefMode == URM_REORDER)
     {
-        //  bisher nur fuer nDz (MoveTab)
+        //  so far only for nDz (MoveTab)
         OSL_ENSURE ( !nDx && !nDy, "URM_REORDER for x and y not yet implemented" );
 
         if ( nDz && (theCol1 >= nCol1) && (theCol2 <= nCol2) &&
@@ -367,9 +367,9 @@ ScRefUpdateRes ScRefUpdate::Update( ScDocument* pDoc, UpdateRefMode eUpdateRefMo
     return eRet;
 }
 
-// simples UpdateReference fuer ScBigRange (ScChangeAction/ScChangeTrack)
-// Referenzen koennen auch ausserhalb des Dokuments liegen!
-// Ganze Spalten/Zeilen (nInt32Min..nInt32Max) bleiben immer solche!
+// simple UpdateReference for ScBigRange (ScChangeAction/ScChangeTrack)
+// References can also be located outside of the document!
+// Whole columns/rows (nInt32Min..nInt32Max) stay as such!
 ScRefUpdateRes ScRefUpdate::Update( UpdateRefMode eUpdateRefMode,
         const ScBigRange& rWhere, sal_Int32 nDx, sal_Int32 nDy, sal_Int32 nDz,
         ScBigRange& rWhat )
@@ -519,7 +519,7 @@ void ScRefUpdate::DoTranspose( SCsCOL& rCol, SCsROW& rRow, SCsTAB& rTab,
         rTab = nNewTab;
     }
     OSL_ENSURE( rCol>=rSource.aStart.Col() && rRow>=rSource.aStart.Row(),
-                "UpdateTranspose: Pos. falsch" );
+                "UpdateTranspose: pos. wrong" );
 
     SCsCOL nRelX = rCol - (SCsCOL)rSource.aStart.Col();
     SCsROW nRelY = rRow - (SCsROW)rSource.aStart.Row();
@@ -551,16 +551,16 @@ ScRefUpdateRes ScRefUpdate::UpdateTranspose(
     return eRet;
 }
 
-//  UpdateGrow - erweitert Referenzen, die genau auf den Bereich zeigen
-//  kommt ohne Dokument aus
+//  UpdateGrow - expands references which point exactly to the area
+//  gets by without document
 
 ScRefUpdateRes ScRefUpdate::UpdateGrow(
     const ScRange& rArea, SCCOL nGrowX, SCROW nGrowY, ScRange& rRef )
 {
     ScRefUpdateRes eRet = UR_NOTHING;
 
-    //  in Y-Richtung darf die Ref auch eine Zeile weiter unten anfangen,
-    //  falls ein Bereich Spaltenkoepfe enthaelt
+    //  in y-direction the Ref may also start one row further below,
+    //  if an area contains column heads
 
     bool bUpdateX = ( nGrowX &&
             rRef.aStart.Col() == rArea.aStart.Col() && rRef.aEnd.Col() == rArea.aEnd.Col() &&
diff --git a/sc/source/core/tool/stringutil.cxx b/sc/source/core/tool/stringutil.cxx
index 53347e7..c18c544 100644
--- a/sc/source/core/tool/stringutil.cxx
+++ b/sc/source/core/tool/stringutil.cxx
@@ -503,7 +503,7 @@ ScInputStringType ScStringUtil::parseInputString(
         aRet.maText = rStr.copy(1);
         aRet.meType = ScInputStringType::Text;
     }
-    else        // (nur) auf englisches Zahlformat testen
+    else        // test for English number format (only)
     {
         sal_uInt32 nNumFormat = rFormatter.GetStandardIndex(eLang);
 
diff --git a/sc/source/core/tool/viewopti.cxx b/sc/source/core/tool/viewopti.cxx
index 9a6b193..b94f6af 100644
--- a/sc/source/core/tool/viewopti.cxx
+++ b/sc/source/core/tool/viewopti.cxx
@@ -41,8 +41,8 @@ void ScGridOptions::SetDefaults()
 {
     *this = ScGridOptions();
 
-    //  Raster-Defaults sind jetzt zwischen den Apps unterschiedlich
-    //  darum hier selber eintragen (alles in 1/100mm)
+    //  grid defaults differ now between the apps
+    //  therefore, enter here in its own right (all in 1/100mm)
 
     if ( ScOptionsUtil::IsMetricSystem() )
     {
@@ -191,7 +191,7 @@ SvxGridItem* ScViewOptions::CreateGridItem() const
     return pItem;
 }
 
-//      ScTpViewItem - Daten fuer die ViewOptions-TabPage
+//      ScTpViewItem - data for the ViewOptions TabPage
 
 ScTpViewItem::ScTpViewItem( sal_uInt16 nWhichP, const ScViewOptions& rOpt )
     :   SfxPoolItem ( nWhichP ),


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/core/tool/rangelst.cxx b/sc/source/core/tool/rangelst.cxx
index 8370f2d..87ca925 100644
--- a/sc/source/core/tool/rangelst.cxx
+++ b/sc/source/core/tool/rangelst.cxx
@@ -166,7 +166,7 @@ ScRefFlags ScRangeList::Parse( const OUString& rStr, ScDocument* pDoc,
         if (!cDelimiter)
             cDelimiter = ScCompiler::GetNativeSymbolChar(ocSep);
 
-        ScRefFlags nResult = ~ScRefFlags::ZERO;    // alle Bits setzen
+        ScRefFlags nResult = ~ScRefFlags::ZERO;    // set all bits
         ScRange aRange;
         const SCTAB nTab = pDoc ? nDefaultTab : 0;
 
@@ -174,7 +174,7 @@ ScRefFlags ScRangeList::Parse( const OUString& rStr, ScDocument* pDoc,
         do
         {
             const OUString aOne = rStr.getToken( 0, cDelimiter, nPos );
-            aRange.aStart.SetTab( nTab );   // Default Tab wenn nicht angegeben
+            aRange.aStart.SetTab( nTab );   // default tab if not specified
             ScRefFlags nRes = aRange.ParseAny( aOne, pDoc, eConv );
             ScRefFlags nEndRangeBits = ScRefFlags::COL2_VALID | ScRefFlags::ROW2_VALID | ScRefFlags::TAB2_VALID;
             ScRefFlags nTmp1 = ( nRes & ScRefFlags::BITS );
@@ -187,11 +187,11 @@ ScRefFlags ScRangeList::Parse( const OUString& rStr, ScDocument* pDoc,
 
             if ( nRes & ScRefFlags::VALID )
                 Append( aRange );
-            nResult &= nRes;        // alle gemeinsamen Bits bleiben erhalten
+            nResult &= nRes;        // all common bits are preserved
         }
         while (nPos >= 0);
 
-        return nResult;             // ScRefFlags::VALID gesetzt wenn alle ok
+        return nResult;             // ScRefFlags::VALID set when all are OK
     }
     else
         return ScRefFlags::ZERO;
@@ -278,20 +278,20 @@ void ScRangeList::Join( const ScRange& r, bool bIsInList )
     {
         ScRange* p = maRanges[i];
         if ( p == pOver )
-            continue;           // derselbe, weiter mit dem naechsten
+            continue;           // the same one, continue with the next
         bool bJoined = false;
         if ( p->In( r ) )
-        {   // Range r in Range p enthalten oder identisch
+        {   //range r included in or identical to range p
             if ( bIsInList )
-                bJoined = true;     // weg mit Range r
+                bJoined = true;     // do away with range r
             else
-            {   // das war's dann
-                bJoinedInput = true;    // nicht anhaengen
+            {   // that was all then
+                bJoinedInput = true;    // don't attach
                 break;  // for
             }
         }
         else if ( r.In( *p ) )
-        {   // Range p in Range r enthalten, r zum neuen Range machen
+        {   // range p included in range r, make r the new range
             *p = r;
             bJoined = true;
         }
@@ -300,12 +300,12 @@ void ScRangeList::Join( const ScRange& r, bool bIsInList )
             if ( p->aStart.Col() == nCol1 && p->aEnd.Col() == nCol2 )
             {
                 if ( p->aStart.Row() == nRow2+1 )
-                {   // oben
+                {   // top
                     p->aStart.SetRow( nRow1 );
                     bJoined = true;
                 }
                 else if ( p->aEnd.Row() == nRow1-1 )
-                {   // unten
+                {   // bottom
                     p->aEnd.SetRow( nRow2 );
                     bJoined = true;
                 }
@@ -313,12 +313,12 @@ void ScRangeList::Join( const ScRange& r, bool bIsInList )
             else if ( p->aStart.Row() == nRow1 && p->aEnd.Row() == nRow2 )
             {
                 if ( p->aStart.Col() == nCol2+1 )
-                {   // links
+                {   // left
                     p->aStart.SetCol( nCol1 );
                     bJoined = true;
                 }
                 else if ( p->aEnd.Col() == nCol1-1 )
-                {   // rechts
+                {   // right
                     p->aEnd.SetCol( nCol2 );
                     bJoined = true;
                 }
@@ -327,15 +327,15 @@ void ScRangeList::Join( const ScRange& r, bool bIsInList )
         if ( bJoined )
         {
             if ( bIsInList )
-            {   // innerhalb der Liste Range loeschen
+            {   // delete range within the list
                 Remove(nOldPos);
                 i--;
                 pOver = nullptr;
                 if ( nOldPos )
-                    nOldPos--;          // Seek richtig aufsetzen
+                    nOldPos--;          // configure seek correctly
             }
             bJoinedInput = true;
-            Join( *p, true );           // rekursiv!
+            Join( *p, true );           // recursive!
         }
     }
     if (  !bIsInList && !bJoinedInput )
@@ -1470,24 +1470,24 @@ void ScRangePairList::Join( const ScRangePair& r, bool bIsInList )
     {
         ScRangePair* p = maPairs[ i ];
         if ( p == pOver )
-            continue;           // derselbe, weiter mit dem naechsten
+            continue;           // the same one, continue with the next
         bool bJoined = false;
         ScRange& rp1 = p->GetRange(0);
         ScRange& rp2 = p->GetRange(1);
         if ( rp2 == r2 )
-        {   // nur wenn Range2 gleich ist
+        {   // only if Range2 is equal
             if ( rp1.In( r1 ) )
-            {   // RangePair r in RangePair p enthalten oder identisch
+            {   // RangePair r included in or identical to RangePair p
                 if ( bIsInList )
-                    bJoined = true;     // weg mit RangePair r
+                    bJoined = true;     // do away with RangePair r
                 else
-                {   // das war's dann
-                    bJoinedInput = true;    // nicht anhaengen
+                {   // that was all then
+                    bJoinedInput = true;    // don't attach
                     break;  // for
                 }
             }
             else if ( r1.In( rp1 ) )
-            {   // RangePair p in RangePair r enthalten, r zum neuen RangePair machen
+            {   // RangePair p included in RangePair r enthalten, make r the new RangePair
                 *p = r;
                 bJoined = true;
             }
@@ -1495,21 +1495,21 @@ void ScRangePairList::Join( const ScRangePair& r, bool bIsInList )
         if ( !bJoined && rp1.aStart.Tab() == nTab1 && rp1.aEnd.Tab() == nTab2
           && rp2.aStart.Tab() == r2.aStart.Tab()
           && rp2.aEnd.Tab() == r2.aEnd.Tab() )
-        {   // 2D, Range2 muss genauso nebeneinander liegen wie Range1
+        {   // 2D, Range2 must be located side-by-side just like Range1
             if ( rp1.aStart.Col() == nCol1 && rp1.aEnd.Col() == nCol2
               && rp2.aStart.Col() == r2.aStart.Col()
               && rp2.aEnd.Col() == r2.aEnd.Col() )
             {
                 if ( rp1.aStart.Row() == nRow2+1
                   && rp2.aStart.Row() == r2.aEnd.Row()+1 )
-                {   // oben
+                {   // top
                     rp1.aStart.SetRow( nRow1 );
                     rp2.aStart.SetRow( r2.aStart.Row() );
                     bJoined = true;
                 }
                 else if ( rp1.aEnd.Row() == nRow1-1
                   && rp2.aEnd.Row() == r2.aStart.Row()-1 )
-                {   // unten
+                {   // bottom
                     rp1.aEnd.SetRow( nRow2 );
                     rp2.aEnd.SetRow( r2.aEnd.Row() );
                     bJoined = true;
@@ -1521,14 +1521,14 @@ void ScRangePairList::Join( const ScRangePair& r, bool bIsInList )
             {
                 if ( rp1.aStart.Col() == nCol2+1
                   && rp2.aStart.Col() == r2.aEnd.Col()+1 )
-                {   // links
+                {   // left
                     rp1.aStart.SetCol( nCol1 );
                     rp2.aStart.SetCol( r2.aStart.Col() );
                     bJoined = true;
                 }
                 else if ( rp1.aEnd.Col() == nCol1-1
                   && rp2.aEnd.Col() == r2.aEnd.Col()-1 )
-                {   // rechts
+                {   // right
                     rp1.aEnd.SetCol( nCol2 );
                     rp2.aEnd.SetCol( r2.aEnd.Col() );
                     bJoined = true;
@@ -1538,15 +1538,15 @@ void ScRangePairList::Join( const ScRangePair& r, bool bIsInList )
         if ( bJoined )
         {
             if ( bIsInList )
-            {   // innerhalb der Liste RangePair loeschen
+            {   // delete RangePair within the list
                 Remove( nOldPos );
                 i--;
                 pOver = nullptr;
                 if ( nOldPos )
-                    nOldPos--;          // Seek richtig aufsetzen
+                    nOldPos--;          // configure seek correctly
             }
             bJoinedInput = true;
-            Join( *p, true );           // rekursiv!
+            Join( *p, true );           // recursive!
         }
     }
     if ( !bIsInList && !bJoinedInput )
@@ -1568,7 +1568,7 @@ ScRangePair** ScRangePairList::CreateNameSortedArray( size_t& nListCount,
         pSortArray[j].pDoc = pDoc;
     }
     qsort( static_cast<void*>(pSortArray), nListCount, sizeof(ScRangePairNameSort), &ScRangePairList_QsortNameCompare );
-    // ScRangePair Pointer aufruecken
+    // move ScRangePair pointer up
     ScRangePair** ppSortArray = reinterpret_cast<ScRangePair**>(pSortArray);
     for ( j=0; j < nListCount; j++ )
     {